getPendingEntries method

  1. @override
Future<List<SyncEntry>> getPendingEntries(
  1. String table,
  2. String recordId
)
override

Get all pending entries for a specific table and record ID. Used during conflict resolution to access the local pending payload.

Implementation

@override
Future<List<SyncEntry>> getPendingEntries(
    String table, String recordId) async {
  final rows = await _db.customSelect(
    'SELECT * FROM dynos_sync_queue '
    'WHERE table_name = ? AND record_id = ? AND synced_at IS NULL '
    'ORDER BY created_at DESC',
    variables: [Variable.withString(table), Variable.withString(recordId)],
  ).get();
  return rows.map(_mapRow).toList();
}