DriftTimestampStore class

TimestampStore implementation backed by a Drift DynosSyncTimestampsTable.

Stores per-table sync timestamps in SQLite via the dynos_sync_timestamps table.

Implemented types

Constructors

DriftTimestampStore(GeneratedDatabase _db)
Creates a DriftTimestampStore backed by the given Drift GeneratedDatabase.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String table) Future<DateTime>
Get the last sync time for a table. Returns epoch if never synced.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String table, DateTime timestamp) Future<void>
Save the sync time for a table.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited