syncedAt property
DateTimeColumn
get
syncedAt
Timestamp when the entry was successfully synced, or null if pending.
Implementation
DateTimeColumn get syncedAt => dateTime().nullable()();
Timestamp when the entry was successfully synced, or null if pending.
DateTimeColumn get syncedAt => dateTime().nullable()();