tableName_ property
TextColumn
get
tableName_
The name of the table the queued record belongs to.
Implementation
TextColumn get tableName_ => text().named('table_name')();
The name of the table the queued record belongs to.
TextColumn get tableName_ => text().named('table_name')();