DynosSyncTimestampsTable class

Drift table for storing per-table sync timestamps.

Add this to your @DriftDatabase(tables: [...]) annotation alongside DynosSyncQueueTable.

Note: Drift's code generator may not resolve this table when imported from an external package. If you see "not understood by drift" warnings, use kSyncTimestampsCreateSql in your migration instead.

Constructors

DynosSyncTimestampsTable()

Properties

customConstraints List<String>
Custom table constraints that should be added to the table.
no setterinherited
dontWriteConstraints bool
Drift will write some table constraints automatically, for instance when you override primaryKey. You can turn this behavior off if you want to. This is intended to be used by generated code only.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isStrict bool
Whether this table is STRICT.
no setterinherited
lastSyncedAt → DateTimeColumn
The last time the corresponding table was successfully synced.
no setter
primaryKey Set<Column<Object>>
Uses tableName_ as the single-column primary key.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableName String
The underlying SQLite table name for sync timestamps.
no setter
tableName_ → TextColumn
The name of the synced table this timestamp belongs to.
no setter
uniqueKeys List<Set<Column<Object>>>?
Unique constraints in this table.
no setterinherited
withoutRowId bool
Whether to append a WITHOUT ROWID clause in the CREATE TABLE statement. This is intended to be used by generated code only.
no setterinherited

Methods

blob() → ColumnBuilder<Uint8List>
Use this as the body of a getter to declare a column that holds arbitrary data blobs, stored as an Uint8List. Example:
inherited
boolean() → ColumnBuilder<bool>
Use this as the body of a getter to declare a column that holds bools. Example (inside the body of a table class):
inherited
customType<T extends Object>(UserDefinedSqlType<T> type) → ColumnBuilder<T>
Defines a column with a custom type when used as a getter.
inherited
dateTime() → ColumnBuilder<DateTime>
Use this as the body of a getter to declare a column that holds date and time values.
inherited
int64() → ColumnBuilder<BigInt>
Use this as the body of a getter to declare a column that holds a 64-big integer as a BigInt.
inherited
integer() → ColumnBuilder<int>
Use this as the body of a getter to declare a column that holds integers.
inherited
intEnum<T extends Enum>() → ColumnBuilder<int>
Creates a column to store an enum class T.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
real() → ColumnBuilder<double>
Use this as the body of a getter to declare a column that holds floating point numbers. Example
inherited
sqliteAny() → ColumnBuilder<DriftAny>
Use this as a the body of a getter to declare a column that holds arbitrary values not modified by drift at runtime.
inherited
text() → ColumnBuilder<String>
Use this as the body of a getter to declare a column that holds strings. Example (inside the body of a table class):
inherited
textEnum<T extends Enum>() → ColumnBuilder<String>
Creates a column to store an enum class T.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited