tableName_ property
TextColumn
get
tableName_
The name of the synced table this timestamp belongs to.
Implementation
TextColumn get tableName_ => text().named('table_name')();
The name of the synced table this timestamp belongs to.
TextColumn get tableName_ => text().named('table_name')();