tableTimestampKeys property
Maps synced table names to their corresponding timestamp column in syncStatusTable.
Implementation
final Map<String, String> tableTimestampKeys;
Maps synced table names to their corresponding timestamp column in syncStatusTable.
final Map<String, String> tableTimestampKeys;