userId property
Returns the current user ID. Called per sync cycle to handle session expiry and account switches.
Implementation
final String Function() userId;
Returns the current user ID. Called per sync cycle to handle session expiry and account switches.
final String Function() userId;