DynosSyncQueueTable class
Drift table definition for the sync queue.
Add this to your @DriftDatabase(tables: [...]) annotation.
Note: Drift's code generator may not resolve this table when imported from an external package. If you see "not understood by drift" warnings, use kSyncQueueCreateSql in your migration instead.
Constructors
Properties
- createdAt → DateTimeColumn
-
Timestamp when the entry was enqueued.
no setter
-
customConstraints
→ List<
String> -
Custom table constraints that should be added to the table.
no setterinherited
- dontWriteConstraints → bool
-
Drift will write some table constraints automatically, for instance when
you override
primaryKey. You can turn this behavior off if you want to. This is intended to be used by generated code only.no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- id → TextColumn
-
Unique identifier for each queued sync entry.
no setter
- isStrict → bool
-
Whether this table is
STRICT.no setterinherited - nextRetryAt → IntColumn
-
Earliest time at which a failed entry may be retried, or null if immediate.
no setter
- operation → TextColumn
-
The sync operation type (e.g. upsert or delete).
no setter
- payload → TextColumn
-
JSON-encoded payload of the record data.
no setter
-
primaryKey
→ Set<
Column< Object> > -
Uses id as the single-column primary key.
no setter
- recordId → TextColumn
-
The primary-key value of the record being synced.
no setter
- retryCount → IntColumn
-
Number of times this entry has been retried.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- syncedAt → DateTimeColumn
-
Timestamp when the entry was successfully synced, or null if pending.
no setter
- tableName → String
-
The underlying SQLite table name for the sync queue.
no setter
- tableName_ → TextColumn
-
The name of the table the queued record belongs to.
no setter
-
uniqueKeys
→ List<
Set< ?Column< >Object> > -
Unique constraints in this table.
no setterinherited
- withoutRowId → bool
-
Whether to append a
WITHOUT ROWIDclause in theCREATE TABLEstatement. This is intended to be used by generated code only.no setterinherited
Methods
-
blob(
) → ColumnBuilder< Uint8List> -
Use this as the body of a getter to declare a column that holds arbitrary
data blobs, stored as an Uint8List. Example:
inherited
-
boolean(
) → ColumnBuilder< bool> -
Use this as the body of a getter to declare a column that holds bools.
Example (inside the body of a table class):
inherited
-
customType<
T extends Object> (UserDefinedSqlType< T> type) → ColumnBuilder<T> -
Defines a column with a custom
typewhen used as a getter.inherited -
dateTime(
) → ColumnBuilder< DateTime> -
Use this as the body of a getter to declare a column that holds date and
time values.
inherited
-
int64(
) → ColumnBuilder< BigInt> -
Use this as the body of a getter to declare a column that holds a 64-big
integer as a BigInt.
inherited
-
integer(
) → ColumnBuilder< int> -
Use this as the body of a getter to declare a column that holds integers.
inherited
-
intEnum<
T extends Enum> () → ColumnBuilder< int> -
Creates a column to store an
enumclassT.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
real(
) → ColumnBuilder< double> -
Use this as the body of a getter to declare a column that holds floating
point numbers. Example
inherited
-
sqliteAny(
) → ColumnBuilder< DriftAny> -
Use this as a the body of a getter to declare a column that holds
arbitrary values not modified by drift at runtime.
inherited
-
text(
) → ColumnBuilder< String> -
Use this as the body of a getter to declare a column that holds strings.
Example (inside the body of a table class):
inherited
-
textEnum<
T extends Enum> () → ColumnBuilder< String> -
Creates a column to store an
enumclassT.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited